"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _GenericLogger_logger, _PinoLogger_logger;
Object.defineProperty(exports, "__esModule", { value: true });
exports.redactSensitiveProps = exports.redactSensitiveHeaders = exports.redact = exports.PinoLogger = exports.GenericLogger = exports.NoOpLogger = void 0;
const fast_copy_1 = __importDefault(require("fast-copy"));
const log_redaction_1 = require("./log-redaction");
class NoOpLogger {
    // eslint-disable-next-line class-methods-use-this
    logSuccess(_response, _options) { }
    // eslint-disable-next-line class-methods-use-this
    logFailure(_error) { }
}
exports.NoOpLogger = NoOpLogger;
class GenericLogger {
    constructor(logger) {
        _GenericLogger_logger.set(this, void 0);
        __classPrivateFieldSet(this, _GenericLogger_logger, logger, "f");
    }
    logSuccess(response, options) {
        const { url, statusCode, timings } = response;
        const message = `${options.method} ${url} ${statusCode} ${new Date().getTime() - timings.start} ms`;
        if (options.method === 'GET') {
            __classPrivateFieldGet(this, _GenericLogger_logger, "f").debug(message);
        }
        else {
            __classPrivateFieldGet(this, _GenericLogger_logger, "f").info(message);
        }
        const redactedOptions = (0, exports.redact)(options);
        __classPrivateFieldGet(this, _GenericLogger_logger, "f").debug('request-options', JSON.stringify(redactedOptions).replace(/\\n/g, ''));
    }
    logFailure(error) {
        var _a, _b, _c, _d;
        const { context, headers, method } = error.options;
        const { requestUrl } = (_a = error.request) !== null && _a !== void 0 ? _a : {};
        const code = (_c = (_b = error.response) === null || _b === void 0 ? void 0 : _b.statusCode) !== null && _c !== void 0 ? _c : error.code;
        const { start, end, error: err } = (_d = error === null || error === void 0 ? void 0 : error.timings) !== null && _d !== void 0 ? _d : {};
        const duration = err && end && start ? (err !== null && err !== void 0 ? err : end) - start : undefined;
        const redactedOptions = (0, exports.redact)(error.options);
        __classPrivateFieldGet(this, _GenericLogger_logger, "f").error('\n' +
            '--------------------------------------------------------------------\n' +
            `${method} ${requestUrl} ${code !== null && code !== void 0 ? code : 'unknown statusCode'} (${duration !== null && duration !== void 0 ? duration : ' - '} ms)\n` +
            `headers: ${JSON.stringify(headers)}\n` +
            `request-options: ${JSON.stringify({ ...redactedOptions, context }).replace(/\\n/g, '')}\n` +
            `error:${error.message}\n` +
            `stack:${error.stack}\n` +
            '--------------------------------------------------------------------');
    }
}
exports.GenericLogger = GenericLogger;
_GenericLogger_logger = new WeakMap();
class PinoLogger {
    constructor(logger) {
        _PinoLogger_logger.set(this, void 0);
        __classPrivateFieldSet(this, _PinoLogger_logger, logger, "f");
    }
    logSuccess(res) {
        var _a, _b;
        const { request: req, timings } = res;
        const level = req.options.method === 'GET' ? 'debug' : 'info';
        __classPrivateFieldGet(this, _PinoLogger_logger, "f")[level]({
            req: {
                method: (_a = req.options) === null || _a === void 0 ? void 0 : _a.method,
                url: (_b = req.options) === null || _b === void 0 ? void 0 : _b.url,
            },
            res: {
                statusCode: res.statusCode,
            },
            responseTime: Number(timings === null || timings === void 0 ? void 0 : timings.end) - Number(timings === null || timings === void 0 ? void 0 : timings.start),
        });
    }
    logFailure(error) {
        var _a, _b;
        const { response: res, request: req, options, timings } = error;
        __classPrivateFieldGet(this, _PinoLogger_logger, "f").error({
            req: {
                method: (_a = req === null || req === void 0 ? void 0 : req.options) === null || _a === void 0 ? void 0 : _a.method,
                url: (_b = req === null || req === void 0 ? void 0 : req.options) === null || _b === void 0 ? void 0 : _b.url,
                headers: options.headers,
                json: options.json,
                failed: true,
            },
            res: {
                statusCode: res.statusCode,
                headers: res.headers,
                body: res.body,
                failed: true,
            },
            err: error,
            responseTime: Number(timings === null || timings === void 0 ? void 0 : timings.end) - Number(timings === null || timings === void 0 ? void 0 : timings.start),
        });
    }
}
exports.PinoLogger = PinoLogger;
_PinoLogger_logger = new WeakMap();
const redact = (options) => {
    const clone = (0, fast_copy_1.default)(options);
    (0, exports.redactSensitiveHeaders)(clone);
    (0, exports.redactSensitiveProps)(clone);
    return clone;
};
exports.redact = redact;
const redactSensitiveHeaders = (options) => {
    var _a;
    if (options.headers === undefined)
        return;
    for (const prop of Object.keys((_a = options.headers) !== null && _a !== void 0 ? _a : {})) {
        for (const propMatch of log_redaction_1.genericLogRedactionKeyPatterns.headers) {
            if (!propMatch.test(prop))
                continue;
            // eslint-disable-next-line no-param-reassign
            options.headers[prop] = '<redacted>';
        }
    }
};
exports.redactSensitiveHeaders = redactSensitiveHeaders;
const redactSensitiveProps = (options) => {
    var _a;
    const jsonOrForm = (_a = options.json) !== null && _a !== void 0 ? _a : options.form;
    if (jsonOrForm === undefined)
        return;
    for (const prop of Object.keys(jsonOrForm)) {
        for (const propMatch of log_redaction_1.genericLogRedactionKeyPatterns.props) {
            if (!propMatch.test(prop))
                continue;
            jsonOrForm[prop] = '<redacted>';
        }
    }
};
exports.redactSensitiveProps = redactSensitiveProps;
//# sourceMappingURL=loggers.js.map