"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jest_each_1 = __importDefault(require("jest-each"));
const loggers_1 = require("./loggers");
describe('log redaction', () => {
    test('should deep clone options', () => {
        const options = {
            headers: {
                authorization: 'a',
            },
            json: {
                password: 'p',
            },
        };
        const actual = (0, loggers_1.redact)(options);
        expect(actual).not.toBe(options);
        expect(actual).toStrictEqual({
            headers: {
                authorization: '<redacted>',
            },
            json: {
                password: '<redacted>',
            },
        });
    });
    (0, jest_each_1.default) `
        input                       | expected
        ${{ ignoreMe: 'ignoreMe' }} | ${{ ignoreMe: 'ignoreMe' }}
        ${{ email: 'e' }}           | ${{ email: '<redacted>' }}
        ${{ Email: 'e' }}           | ${{ Email: '<redacted>' }}
        ${{ password: 'p' }}        | ${{ password: '<redacted>' }}
        ${{ Password: 'p' }}        | ${{ Password: '<redacted>' }}
        ${{ pass: 'p' }}            | ${{ pass: '<redacted>' }}
        ${{ Pass: 'p' }}            | ${{ Pass: '<redacted>' }}
        ${{ User: 'u' }}            | ${{ User: '<redacted>' }}
        ${{ user: 'u' }}            | ${{ user: '<redacted>' }}
        ${{ Username: 'u' }}        | ${{ Username: '<redacted>' }}
        ${{ username: 'u' }}        | ${{ username: '<redacted>' }}
        ${{ client_id: 'i' }}       | ${{ client_id: '<redacted>' }}
        ${{ clientId: 'i' }}        | ${{ clientId: '<redacted>' }}
        ${{ ClientId: 'i' }}        | ${{ ClientId: '<redacted>' }}
        ${{ client_secret: 's' }}   | ${{ client_secret: '<redacted>' }}
        ${{ clientSecret: 's' }}    | ${{ clientSecret: '<redacted>' }}
        ${{ ClientSecret: 's' }}    | ${{ ClientSecret: '<redacted>' }}
        ${{ token: 't' }}           | ${{ token: '<redacted>' }}
        ${{ Token: 't' }}           | ${{ Token: '<redacted>' }}
    `.describe('redact $input', ({ input, expected }) => {
        test(`from 'json'`, () => {
            const actual = { json: input };
            (0, loggers_1.redactSensitiveProps)(actual);
            expect(actual.json).toStrictEqual(expected);
        });
        test(`from 'form'`, () => {
            const actual = { form: input };
            (0, loggers_1.redactSensitiveProps)(actual);
            expect(actual.form).toStrictEqual(expected);
        });
    });
    (0, jest_each_1.default) `
    input | expected
      ${{ authorization: 'a' }} | ${{ authorization: '<redacted>' }},
      ${{ Authorization: 'a' }} | ${{ Authorization: '<redacted>' }},
  `.test('redact $input from headers', ({ input, expected }) => {
        const actual = { headers: input };
        (0, loggers_1.redactSensitiveHeaders)(actual);
        expect(actual.headers).toStrictEqual(expected);
    });
});
//# sourceMappingURL=loggers.test.js.map